# Correction

## Preparation

Build proxy image with nginx inside.

```bash
docker build --tag proxy .
```

## Intranet

Sur le serveur `wserver`:

On copie de la page web de la sceance 2.

```bash
cp /share/votre-page-web.html /var/www/html/index1.html
```

On verifie le status du service apache2, et le demarrons si ce n'est pas deja fait.

```bash
systemctl status apache2.service
systemctl start apache2.service
```

On creer un virtual host apache2 pour notre site web.

```bash
cp /etc/apache2/sites-available/{000-default,100.10.0.3}.conf
nano /etc/apache2/sites-available/100.10.0.3.conf
```

```conf
<VirtualHost *:80>
    # The ServerName directive sets the request scheme, hostname and port that
    # the server uses to identify itself. This is used when creating
    # redirection URLs. In the context of virtual hosts, the ServerName
    # specifies what hostname must appear in the request's Host: header to
    # match this virtual host. For the default virtual host (this file) this
    # value is not decisive as it is used as a last resort host regardless.
    # However, you must set it for any further virtual host explicitly.
    ServerName 100.10.0.3

    ServerAdmin webmaster@localhost
    DocumentRoot /var/www/html

    # Available loglevels: trace8, ..., trace1, debug, info, notice, warn,
    # error, crit, alert, emerg.
    # It is also possible to configure the loglevel for particular
    # modules, e.g.
    #LogLevel info ssl:warn

    ErrorLog ${APACHE_LOG_DIR}/error.log
    CustomLog ${APACHE_LOG_DIR}/access.log combined

    # For most configuration files from conf-available/, which are
    # enabled or disabled at a global level, it is possible to
    # include a line for only one particular virtual host. For example the
    # following line enables the CGI configuration for this host only
    # after it has been globally disabled with "a2disconf".
    #Include conf-available/serve-cgi-bin.conf
</VirtualHost>
```

On desactive le vhost par default et activons le notre.

```bash
a2dissite 000-default
a2ensite 100.10.0.3
```

On verifie que la configuration n'a pas d'erreur de syntax, et on reload le service avec la nouvelle configuration.

```bash
apache2ctl configtest
systemctl reload apache2.service
```

## DMZ

### Web proxy

On verifie le status du service nginx, et le demarrons si ce n'est pas deja fait.

```bash
systemctl status nginx.service
systemctl start nginx.service
```

On creer un virtual host nginx pour notre proxy.

```bash
cp /etc/nginx/sites-available/{default,100.10.0.131.conf}
nano /etc/nginx/sites-available/100.10.0.131.conf
```

```conf
server {
    listen 80 default_server;

    server_name _;

    location / {
        proxy_set_header Host $host;
        proxy_set_header X-Real-IP $remote_addr;
        proxy_pass http://100.10.0.3:80;
    }
}
```

On desactive le vhost par default et activons le notre.

```bash
unlink /etc/nginx/sites-enabled/default
ln -s /etc/nginx/sites-available/100.10.0.131.conf /etc/nginx/sites-enabled/100.10.0.131.conf
```

On verifie que la configuration n'a pas d'erreur de syntax, et on reload le service avec la nouvelle configuration.

```bash
nginx -t
systemctl reload nginx.service
```

### Firewall 1
 
pour visualiser les informations relatives au noeud

```bash
ip addr

telnet localhost zebra

mot de passe à entrer : zebra
enable
zebra# configure terminal
zebra(config)# interface eth0
zebra(config-if)# ip address 100.10.0.1/25  
zebra(config-if)# no shutdown
zebra(config-if)# link-detect
zebra(config-if)# quit
zebra(config)# interface eth1
zebra(config-if)# ip address 100.10.0.129/25 
zebra(config-if)# no shutdown
zebra(config-if)# link-detect
zebra(config-if)# quit
zebra(config)# ip route 200.10.0.0/16 100.10.0.130
zebra(config)# quit
zebra# show ip route
Codes: K - kernel route, C - connected, S - static, R - RIP,
       O - OSPF, I - IS-IS, B - BGP, P - PIM, A - Babel, N - NHRP,
       > - selected route, * - FIB route

C>* 100.10.0.0/25 is directly connected, eth0
C>* 100.10.0.128/25 is directly connected, eth1
C>* 127.0.0.0/8 is directly connected, lo
S>* 200.10.0.0/16 [1/0] via 100.10.0.130, eth1
zebra# 
zebra# exit
```

On verifie le status du service nftables, et le demarrons si ce n'est pas deja fait.

```bash
systemctl status nftables.service
systemctl start nftables.service
```

Lister la configuration en cours nftables

```bash
nft list ruleset
```

Voir une table en particulier

```bash
nft list tables
nft list table inet filter
```

Configuration de nftables

```bash
nano /etc/nftables.conf
```

```txt
#!/usr/sbin/nft -f

flush ruleset

table inet filter {
    chain input {
        type filter hook input priority filter; policy drop;

        iifname lo accept \
        comment "Accept any localhost traffic"

        ct state { established; related } accept \
        comment "Accept traffic originated from us"

        ct state invalid drop \
        comment "Drop invalid connections"

        log prefix "[nftables] Inbound Denied: " counter drop \
        comment "Logging of denied inbound traffic"
    }

    chain forward {
        type filter hook forward priority filter; policy drop;

        ct state { established; related } accept \
        comment "Accept established and related traffic"

        ct state invalid drop \
        comment "Drop invalid connections"

        ip protocol icmp icmp type {
            echo-reply,  # type 0
            destination-unreachable,  # type 3
            echo-request,  # type 8
            time-exceeded;  # type 11
            parameter-problem,  # type 12
        } accept \
        comment "Accept ICMP"

        iifname eth0 accept \
        comment "Accept all LAN traffic"

        ip saddr 100.10.0.131 ip daddr 100.10.0.3 tcp dport 80 accept \
        comment "Accept HTTP from proxy server to wserver"

        log prefix "[nftables] Forward Denied: " counter drop \
        comment "Logging of denied forward traffic"
    }

    chain output {
        type filter hook output priority filter; policy accept;
    }
}
```

On reload la configuration

```bash
systemctl reload nftables.service
```

On test, et si tout est bon, on enable le service pour que les regles s'appliquer a chaque demarrage

```bash
systemctl enable nftables.service
```

### Firewall 2

```bash
ifconfig

telnet localhost zebra

mot de passe à entrer : zebra

zebra> enable
Password: 
zebra# configure terminal
zebra(config)# interface eth0 
zebra(config-if)# ip address 100.10.0.130/25
zebra(config-if)#  no shutdown
zebra(config-if)# link-detect
zebra(config-if)# quit
zebra(config)# interface eth1
zebra(config-if)# ip address 200.10.0.1/16
zebra(config-if)#  no shutdown
zebra(config-if)# link-detect
zebra(config-if)#  quit
zebra(config)# ip route 100.10.0.0/25 100.10.0.129

zebra(config-if)#  quit
zebra(config)# ip route 100.10.0.0/25 100.10.0.129
zebra(config)# quit
zebra# show ip route
Codes: K - kernel route, C - connected, S - static, R - RIP,
       O - OSPF, I - IS-IS, B - BGP, P - PIM, A - Babel, N - NHRP,
       > - selected route, * - FIB route

S>* 100.10.0.0/25 [1/0] via 100.10.0.129, eth0
C>* 100.10.0.128/25 is directly connected, eth0
C>* 127.0.0.0/8 is directly connected, lo
C>* 200.10.0.0/16 is directly connected, eth1
zebra# 
zebra# exit
```

On verifie le status du service nftables, et le demarrons si ce n'est pas deja fait.

```bash
systemctl status nftables.service
systemctl start nftables.service
```

Lister la configuration en cours nftables

```bash
nft list ruleset
```

Configuration de nftables

```bash
nano /etc/nftables.conf
```

```txt
#!/usr/sbin/nft -f

flush ruleset

table inet filter {
    chain input {
        type filter hook input priority filter; policy drop;

        iifname lo accept \
        comment "Accept any localhost traffic"

        ct state { established; related } accept \
        comment "Accept traffic originated from us"

        ct state invalid drop \
        comment "Drop invalid connections"

        log prefix "[nftables] Inbound Denied: " counter drop \
        comment "Logging of denied inbound traffic"
    }

    chain forward {
        type filter hook forward priority filter; policy drop;

        ct state { established; related } accept \
        comment "Accept established and related traffic"

        ct state invalid drop \
        comment "Drop invalid connections"

        ip protocol icmp icmp type {
            echo-reply,  # type 0
            destination-unreachable,  # type 3
            echo-request,  # type 8
            time-exceeded;  # type 11
            parameter-problem,  # type 12
        } accept \
        comment "Accept ICMP"

        iifname eth0 accept \
        comment "Accept all LAN traffic"

        ip daddr 100.10.0.131 tcp dport 80 accept \
        comment "Accept HTTP from any to proxy"

        log prefix "[nftables] Forward Denied: " counter drop \
        comment "Logging of denied forward traffic"
    }

    chain output {
        type filter hook output priority filter; policy accept;
    }
}
```

On reload la configuration

```bash
systemctl reload nftables.service
```

On test, et si tout est bon, on enable le service pour que les regles s'appliquer a chaque demarrage

```bash
systemctl enable nftables.service
```

## HTTPS

To do

---

editer le fichier /etc/apache2/sites-available/100.10.0.3.conf

```bash
nano /etc/apache2/sites-available/100.10.0.3.conf
```

```conf
<VirtualHost *:80>
    ServerName 100.10.0.3 
    DocumentRoot /var/www/html   
</VirtualHost>

<VirtualHost *:443>
    ServerName 100.10.0.3
    DocumentRoot /var/www/html

    SSLEngine on
    SSLCertificateFile /etc/ssl/certs/apache-selfsigned.crt
    SSLCertificateKeyFile /etc/ssl/private/apache-selfsigned.key
</VirtualHost>
```

```bash
openssl x509 -in /etc/ssl/certs/apache-selfsigned.crt -text -noout command

Country Name (2 letter code) [XX]:FR
State or Province Name (full name) []: FR
Locality Name (eg, city) [Default City]:BREST  
Organization Name (eg, company) [Default Company Ltd]:MA COMPAGNIE
Organizational Unit Name (eg, section) []: DEPARTEMENT
Common Name (eg, your name or your server's hostname) []:100.10.0.3 
Email Address []:
```

```bash
a2ensite 100.10.0.3.conf
service apache2 reload 
```
